CommonGoogleGenPlugin class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
knownModels
→ Map<
String, ModelInfo> -
Curated per-model capability metadata exposed by this plugin, keyed by
bare model name.
no setter
- name → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createEmbedder(
String embedderName) → Embedder -
createModel(
String modelName, SchemanticType customOptions) → Model -
getApiClient(
[String? requestApiKey]) → Future< GenerativeLanguageBaseClient> -
handleException(
Object e, StackTrace stack) → GenkitException -
init(
) → Future< List< Action> > -
Called when the plugin is initialized.
inherited
-
list(
) → Future< List< ActionMetadata> > -
Called to list actions provided by the plugin.
inherited
-
middleware(
) → List< GenerateMiddlewareDef> -
Middleware provided by the plugin.
inherited
-
model(
String name) → Model -
inherited
-
modelInfoFor(
String modelName) → ModelInfo -
Returns the capability metadata for
modelName, falling back to commonModelInfo for names not in knownModels. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
String actionType, String name) → Action? - Called to resolve an action by name.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited