KnownGemmaModel enum
Gemma models the Gemini API serves, curated the same way as KnownGeminiModel.
Values
- gemma431b → const KnownGemmaModel
-
const KnownGemmaModel('gemma-4-31b-it', 'Gemma 4 31B') - gemma426bA4b → const KnownGemmaModel
-
const KnownGemmaModel('gemma-4-26b-a4b-it', 'Gemma 4 26B A4B')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Bare model name (no plugin prefix).
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- info → ModelInfo
-
The multimodal capability profile for this model.
no setter
- label → String
-
Human-readable label surfaced in listings.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KnownGemmaModel> - A constant List of the values in this enum, in order of their declaration.